@@ -210,7 +210,7 @@ def mkfs(device, fs_type, label):
     assert (os.path.exists(device))
 
     args = ['/sbin/mkfs',
-            '-v'
+            '-v',
             '-t', fs_type,
             '-L', label,
             device]
